@@ -54,6 +54,34 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateCallOutSession(self, request):
+        """创建外呼会话
+
+        :param request: Request instance for CreateCallOutSession.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.CreateCallOutSessionRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.CreateCallOutSessionResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreateCallOutSession", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateCallOutSessionResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateSDKLoginToken(self, request):
         """创建 SDK 登录 Token。
 
@@ -110,6 +138,34 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateUserSig(self, request):
+        """创建用户数据签名
+
+        :param request: Request instance for CreateUserSig.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.CreateUserSigRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.CreateUserSigResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreateUserSig", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateUserSigResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeleteStaff(self, request):
         """删除坐席信息
 
@@ -138,6 +194,90 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeAutoCalloutTasks(self, request):
+        """批量查询自动任务外呼
+
+        :param request: Request instance for DescribeAutoCalloutTasks.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.DescribeAutoCalloutTasksRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.DescribeAutoCalloutTasksResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeAutoCalloutTasks", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeAutoCalloutTasksResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeCCCBuyInfoList(self, request):
+        """获取用户购买信息列表
+
+        :param request: Request instance for DescribeCCCBuyInfoList.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.DescribeCCCBuyInfoListRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.DescribeCCCBuyInfoListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeCCCBuyInfoList", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeCCCBuyInfoListResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeCallInMetrics(self, request):
+        """获取呼入实时数据统计指标
+
+        :param request: Request instance for DescribeCallInMetrics.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.DescribeCallInMetricsRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.DescribeCallInMetricsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeCallInMetrics", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeCallInMetricsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeChatMessages(self, request):
         """包括具体聊天内容
 
@@ -308,6 +448,34 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeStaffStatusMetrics(self, request):
+        """获取坐席实时状态统计指标
+
+        :param request: Request instance for DescribeStaffStatusMetrics.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.DescribeStaffStatusMetricsRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.DescribeStaffStatusMetricsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeStaffStatusMetrics", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeStaffStatusMetricsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeTelCallInfo(self, request):
         """按实例获取电话消耗统计
 
